package com.rwk.web.controller.ability;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.rwk.common.annotation.Log;
import com.rwk.common.enums.BusinessType;
import com.rwk.system.domain.RwkMeetingFile;
import com.rwk.system.service.IRwkMeetingFileService;
import com.rwk.common.core.controller.BaseController;
import com.rwk.common.core.domain.AjaxResult;
import com.rwk.common.utils.poi.ExcelUtil;
import com.rwk.common.core.page.TableDataInfo;

/**
 * 【教育培训附件】Controller
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
@Controller
@RequestMapping("/system/file")
public class RwkMeetingFileController extends BaseController
{
    private String prefix = "system/file";

    @Autowired
    private IRwkMeetingFileService rwkMeetingFileService;

    @RequiresPermissions("system:file:view")
    @GetMapping()
    public String file()
    {
        return prefix + "/file";
    }

    /**
     * 查询【教育培训附件】列表
     */
    @RequiresPermissions("system:file:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(RwkMeetingFile rwkMeetingFile)
    {
        startPage();
        List<RwkMeetingFile> list = rwkMeetingFileService.selectRwkMeetingFileList(rwkMeetingFile);
        return getDataTable(list);
    }

    /**
     * 导出【教育培训附件】列表
     */
    @RequiresPermissions("system:file:export")
    @Log(title = "【教育培训附件】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(RwkMeetingFile rwkMeetingFile)
    {
        List<RwkMeetingFile> list = rwkMeetingFileService.selectRwkMeetingFileList(rwkMeetingFile);
        ExcelUtil<RwkMeetingFile> util = new ExcelUtil<RwkMeetingFile>(RwkMeetingFile.class);
        return util.exportExcel(list, "【教育培训附件】数据");
    }

    /**
     * 新增【教育培训附件】
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存【教育培训附件】
     */
    @RequiresPermissions("system:file:add")
    @Log(title = "【教育培训附件】", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(RwkMeetingFile rwkMeetingFile)
    {
        return toAjax(rwkMeetingFileService.insertRwkMeetingFile(rwkMeetingFile));
    }

    /**
     * 修改【教育培训附件】
     */
    @RequiresPermissions("system:file:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        RwkMeetingFile rwkMeetingFile = rwkMeetingFileService.selectRwkMeetingFileById(id);
        mmap.put("rwkMeetingFile", rwkMeetingFile);
        return prefix + "/edit";
    }

    /**
     * 修改保存【教育培训附件】
     */
    @RequiresPermissions("system:file:edit")
    @Log(title = "【教育培训附件】", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(RwkMeetingFile rwkMeetingFile)
    {
        return toAjax(rwkMeetingFileService.updateRwkMeetingFile(rwkMeetingFile));
    }

    /**
     * 删除【教育培训附件】
     */
    @RequiresPermissions("system:file:remove")
    @Log(title = "【教育培训附件】", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(rwkMeetingFileService.deleteRwkMeetingFileByIds(ids));
    }
}
