package com.rwk.system.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.rwk.common.core.domain.entity.SysUser;
import com.rwk.common.utils.ShiroUtils;
import com.rwk.system.domain.RwkBookGroup;
import com.rwk.system.mapper.RwkBookGroupMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.rwk.system.mapper.RwkAddressBookMapper;
import com.rwk.system.domain.RwkAddressBook;
import com.rwk.system.service.IRwkAddressBookService;
import com.rwk.common.core.text.Convert;

/**
 * 通讯录主Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-12-11
 */
@Service
public class RwkAddressBookServiceImpl implements IRwkAddressBookService 
{
    @Autowired
    private RwkAddressBookMapper rwkAddressBookMapper;

    @Autowired
    private RwkBookGroupMapper rwkBookGroupMapper;

    /**
     * 查询通讯录主
     * 
     * @param id 通讯录主主键
     * @return 通讯录主
     */
    @Override
    public RwkAddressBook selectRwkAddressBookById(Long id)
    {
        return rwkAddressBookMapper.selectRwkAddressBookById(id);
    }

    /**
     * 查询通讯录主列表
     * 
     * @param rwkAddressBook 通讯录主
     * @return 通讯录主
     */
    @Override
    public List<RwkAddressBook> selectRwkAddressBookList(RwkAddressBook rwkAddressBook)
    {
        List<RwkAddressBook> list = new ArrayList<RwkAddressBook>();
        String keyword = rwkAddressBook.getKeyword();
        SysUser sysUser = ShiroUtils.getSysUser();
        rwkAddressBook.setDeptId(sysUser.getDeptId());
        if (keyword.equals("未分组联系人")){
            list= rwkAddressBookMapper.selectRwkAddressBookListKeyWord(rwkAddressBook);
        }else {
            list= rwkAddressBookMapper.selectRwkAddressBookList(rwkAddressBook);
        }
        return list;
    }

    /**
     * 新增通讯录主
     * 
     * @param rwkAddressBook 通讯录主
     * @return 结果
     */
    @Override
    public int insertRwkAddressBook(RwkAddressBook rwkAddressBook)
    {

        RwkBookGroup rbg= new RwkBookGroup();
        rbg.setGroupId(rwkAddressBook.getAddressGroup());
        rwkAddressBookMapper.insertRwkAddressBook(rwkAddressBook);
        rbg.setBookId(rwkAddressBook.getId());
        rwkAddressBook.setCreateDate(new Date());
        return rwkBookGroupMapper.insertRwkBookGroup(rbg);
    }

    /**
     * 修改通讯录主
     * 
     * @param rwkAddressBook 通讯录主
     * @return 结果
     */
    @Override
    public int updateRwkAddressBook(RwkAddressBook rwkAddressBook)
    {
        return rwkAddressBookMapper.updateRwkAddressBook(rwkAddressBook);
    }

    /**
     * 批量删除通讯录主
     * 
     * @param ids 需要删除的通讯录主主键
     * @return 结果
     */
    @Override
    public int deleteRwkAddressBookByIds(String ids)
    {
        rwkBookGroupMapper.deleteRwkBookGroupByBookIds(Convert.toStrArray(ids));
        return rwkAddressBookMapper.deleteRwkAddressBookByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除通讯录主信息
     * 
     * @param id 通讯录主主键
     * @return 结果
     */
    @Override
    public int deleteRwkAddressBookById(Long id)
    {
        return rwkAddressBookMapper.deleteRwkAddressBookById(id);
    }
}
